@@ -1,7 +1,8 @@
 try:
     import matplotlib.pyplot as plt
-    import matplotlib as mpl
-    from numba import jit
+    from PIL import Image
+    from PIL import ImageFont
+    from PIL import ImageDraw
     import numpy as np
     import cv2
 except ImportError as e:
